﻿using Exam.Infrastructure.Data.Entity;
using Exam.Share;
using Exam.Share.ViewResponses.Exam;
using Hotline.Application.Exam.Constants.ApiRoutes;
using Hotline.Application.Exam.Interface.ExamManages;
using Hotline.Share.Requests.Exam;
using Microsoft.AspNetCore.Mvc;

namespace Hotline.Api.Controllers.Exam
{
    public class ExamManageController : BaseController
    {
        private readonly IExamManageService _questionService;
        public ExamManageController(IExamManageService questionService)
        {
            _questionService = questionService;
        }

        /// <summary>
        /// 新增题库
        /// </summary>
        /// <param name="questionDto"></param>
        /// <returns></returns>
        [HttpPost(ExamManageApiRoute.Add)]
        public async Task Add([FromBody] AddExamManageDto questionDto)
        {
            await _questionService.AddAsync(questionDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 修改题库
        /// </summary>
        /// <param name="questionDto"></param>
        /// <returns></returns>
        [HttpPut(ExamManageApiRoute.Update)]
        public async Task Update([FromBody] UpdateExamManageDto questionDto)
        {
            await _questionService.UpdateAsync(questionDto, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 删除题库
        /// </summary>
        /// <param name="entityQueryRequest"></param>
        /// <returns></returns>
        [HttpDelete(ExamManageApiRoute.Delete)]
        public async Task Delete([FromBody] EntityQueryRequest entityQueryRequest)
        {
            await _questionService.DeleteAsync(entityQueryRequest, HttpContext.RequestAborted);
        }

        /// <summary>
        /// 获取题库分页列表
        /// </summary>
        /// <param name="questionPagedRequest"></param>
        /// <returns></returns>
        [HttpPost(ExamManageApiRoute.GetPagedList)]
        public async Task<ExamManagePageViewResponse> GetPagedList([FromBody] ExamManagePagedRequest questionPagedRequest)
        {
            var questionPageViewResponse = await _questionService.GetPagedListAsync(questionPagedRequest);

            return questionPageViewResponse as ExamManagePageViewResponse;
        }

        /// <summary>
        /// 获取题库
        /// </summary>
        /// <param name="id"></param>
        /// <returns></returns>
        [HttpGet(ExamManageApiRoute.Get)]
        public async Task<ExamManageDto> Get(string id)
        {
            var questionDto = await _questionService.GetAsync(new EntityQueryRequest
            {
                Id = id
            });

            return questionDto;
        }
    }
}
