﻿using Exam.Infrastructure.Data.Entity;
using Exam.Infrastructure.Data.Interface;
using Exam.Infrastructure.Extensions;
using XF.Domain.Entities;
using XF.Domain.Repository;

namespace Hotline.Repository.SqlSugar.Extensions
{
    public static class ApiServiceExtension
    {
        public static void ToInsert<T>(this T entity) where T : class, IEntity<string>, new()
        {
            if (entity.Id.IsNullOrEmpty())
            {
                if (entity is Entity)
                {
                    (entity as Entity)?.InitId();
                }
            }

            if (entity is CreationEntity)
            {
                var creationEntity = entity as CreationEntity;
                if (creationEntity != null)
                {
                    creationEntity.CreationTime = DateTime.Now;
                }

            }
        }

        public static void ToInsert<T>(this List<T> entities) where T : class, IEntity<string>, new()
        {
            foreach(var entity in entities)
            {
                entity.ToInsert();
            }
        }

        public static void ToUpdate<T>(this T entity) where T : class, IEntity<string>, new()
        {
            if(entity is FullStateEntity)
            {
                var fullStateEntity = entity as FullStateEntity;
                if (fullStateEntity != null)
                    fullStateEntity.LastModificationTime = DateTime.Now;

                    entity = fullStateEntity as T ?? entity;
                
            }          
        }

        public static void ToUpdate<T>(this List<T> entities) where T : class, IEntity<string>, new()       
        {
            foreach (var entity in entities)
            {
                entity.ToUpdate();
            }
        }
    }
}
